# django-app-base

部门权限的作用，部门就是类似人员组，只需要将权限设置在人员组上，并不需要有具体的员工，只要有员工进来就可以获得相应的角色

pip install /d/xunull-repository/xunull-github/public/django-user-role/dist/django_user_role-0.0.1.tar.gz

pip install /d/xunull-repository/xunull-github/public/simple-common/dist/simple_common-0.0.1.tar.gz

python -m django test --settings=tests.settings

python setup.py sdist bdist_wheel
